# API Reference

This section provides detailed documentation for the pyvista-js public API.

## Plotting

```{eval-rst}
.. autosummary::
   :toctree: _autosummary
   :nosignatures:

   pyvista_js.Plotter
```

## Camera

```{eval-rst}
.. autosummary::
   :toctree: _autosummary
   :nosignatures:

   pyvista_js.Camera
```

## Lighting

```{eval-rst}
.. autosummary::
   :toctree: _autosummary
   :nosignatures:

   pyvista_js.Light
```

## Data

```{eval-rst}
.. autosummary::
   :toctree: _autosummary
   :nosignatures:

   pyvista_js.PointData
```

## Mesh

```{eval-rst}
.. autosummary::
   :toctree: _autosummary
   :nosignatures:

   pyvista_js.PolyData
   pyvista_js.Arrow
   pyvista_js.Sphere
   pyvista_js.Cube
   pyvista_js.Cylinder
   pyvista_js.Cone
   pyvista_js.Plane
   pyvista_js.Disc

   pyvista_js.Circle
   pyvista_js.Line
```

## Texture

```{eval-rst}
.. autosummary::
   :toctree: _autosummary
   :nosignatures:

   pyvista_js.Texture
```

## Filters

```{eval-rst}
.. autosummary::
   :toctree: _autosummary
   :nosignatures:

   pyvista_js.PolyData.clip
   pyvista_js.PolyData.shrink
   pyvista_js.PolyData.texture_map_to_plane
   pyvista_js.PolyData.tube
```

## Readers

```{eval-rst}
.. autosummary::
   :toctree: _autosummary
   :nosignatures:

   pyvista_js.OBJReader
   pyvista_js.PLYReader
   pyvista_js.PolyDataReader
   pyvista_js.STLReader
```

## Examples

```{eval-rst}
.. autosummary::
   :toctree: _autosummary
   :nosignatures:

   pyvista_js.examples.CubeMap
   pyvista_js.examples.download_masonry_texture
   pyvista_js.examples.download_sky_box_cube_map
```

## CLI

```{eval-rst}
.. autosummary::
   :toctree: _autosummary
   :nosignatures:

   pyvista_js._cli.main
```
